@@ -62,7 +62,7 @@ from lfmaptools.epsg_defs import webmerc, wgs84
 from lfmaptools.geotools import EastingNorthing_TM, LatLon_TM, LatLon_TM_polygonize
 from lfmaptools.interptools import interp_weights, interpolate
 from lfmaptools.mapping import add_stamen_basemap
-from lfmaptools.netcdf_utils import nc2xr, nc_max, nc_min, nc_min_max
+from lfmaptools.netcdf_utils import nc2xr, nc_max, nc_min, nc_min_max, nc_vars
 from lfmaptools.utilities import (
     _decompress_gz,
     _nice_round,
@@ -1158,6 +1158,16 @@ class LaharFlowData(object):
 
     def _get_data_nc(self, LaharFlowFile, vars=None):
 
+        nc_variables = nc_vars(LaharFlowFile)
+
+        if vars is not None:
+            for v in vars:
+                if v not in nc_variables:
+                    raise RuntimeWarning(
+                        f"Variable {v} is not in netcdf file {LaharFlowFile}, skipping..."
+                    )
+                    vars.remove(v)
+
         raster = nc2xr(LaharFlowFile, vars=vars)
         coords = list(raster.coords.keys())
         if "x_distance" in coords:
